==> boost-docs-1.84.0.tgz: share/doc/boost/libs/redis/doc/html/search/all_2.js <==
var searchData=
[
  ['cancel_0',['cancel',['../classboost_1_1redis_1_1basic__connection.html#ab91c1de2894180d9bc9ae35b188f078a',1,'boost::redis::basic_connection::cancel()'],['../classboost_1_1redis_1_1connection.html#a95d4d441d5cc6e9809de9e18c2a19ca8',1,'boost::redis::connection::cancel()'],['../classboost_1_1redis_1_1detail_1_1connection__base.html#ae0f65b3d236d7f48b8374efc2b0fd357',1,'boost::redis::detail::connection_base::cancel()']]],
  ['cancel_5fif_5fnot_5fconnected_1',['cancel_if_not_connected',['../classboost_1_1redis_1_1request.html#a3225a8a42083e807cd7b699bbd33707a',1,'boost::redis::request::config']]],
  ['cancel_5fif_5funresponded_2',['cancel_if_unresponded',['../classboost_1_1redis_1_1request.html#abbc65c9264a6732bdd157078507479ab',1,'boost::redis::request::config']]],
  ['cancel_5fon_5fconnection_5flost_3',['cancel_on_connection_lost',['../classboost_1_1redis_1_1request.html#ad871157d771d49b6ea3cd0707280256f',1,'boost::redis::request::config']]],
  ['clear_4',['clear',['../classboost_1_1redis_1_1request.html#ac880af0951bfae6b89913913ac709557',1,'boost::redis::request']]],
  ['clientname_5',['clientname',['../group__high-level-api.html#a3388584bc6c20946f824e35602b51c4e',1,'boost::redis::config']]],
  ['commands_5fsent_6',['commands_sent',['../group__high-level-api.html#a8f06258bcaad903476f39a56e9049c61',1,'boost::redis::usage']]],
  ['config_7',['config',['../group__high-level-api.html#structboost_1_1redis_1_1config',1,'boost::redis::config'],['../classboost_1_1redis_1_1request.html#structboost_1_1redis_1_1request_1_1config',1,'boost::redis::request::config']]],
  ['connect_8',['connect',['../group__high-level-api.html#ggaaf95d0d45b3829342e8adff2d6c3fcbeab640a0ce465fa2a4150c36b305c1c11b',1,'boost::redis']]],
  ['connect_5ftimeout_9',['connect_timeout',['../group__high-level-api.html#ac01a8bcfc1acd353acc62b69f0648442',1,'boost::redis::config::connect_timeout()'],['../group__high-level-api.html#gga657dd981aeeec394a381d3fb4a2222bea68fe378b7acbea462cde519f2d27ed71',1,'connect_timeout()boost::redis']]],
  ['connection_10',['connection',['../classboost_1_1redis_1_1connection.html',1,'boost::redis::connection'],['../classboost_1_1redis_1_1connection.html#a68cfce1ed9affe06f6f2b0e84d6d8dbd',1,'boost::redis::connection::connection(executor_type ex, asio::ssl::context::method method=asio::ssl::context::tls_client, std::size_t max_read_size=(std::numeric_limits&lt; std::size_t &gt;::max)())'],['../classboost_1_1redis_1_1connection.html#ab006ce3e2f5a2024abbf8853ca37589c',1,'boost::redis::connection::connection(asio::io_context &amp;ioc, asio::ssl::context::method method=asio::ssl::context::tls_client, std::size_t max_read_size=(std::numeric_limits&lt; std::size_t &gt;::max)())']]],
  ['connection_5fbase_11',['connection_base',['../classboost_1_1redis_1_1detail_1_1connection__base.html',1,'boost::redis::detail::connection_base&lt; Executor &gt;'],['../classboost_1_1redis_1_1detail_1_1connection__base.html#a5cf3308f2e1aea63dc0fade071ab80de',1,'boost::redis::detail::connection_base::connection_base()']]],
  ['connection_5fbase_3c_20executor_5ftype_20_3e_12',['connection_base&lt; executor_type &gt;',['../classboost_1_1redis_1_1detail_1_1connection__base.html',1,'boost::redis::detail']]],
  ['crit_13',['crit',['../group__high-level-api.html#gga4f66f8e4497ccf09e57440515d806feba5888c6a8bb862595985926d16c7dcf13',1,'boost::redis::logger']]]
];

==> boost-docs-1.87.0.tgz: share/doc/boost/libs/redis/doc/html/search/all_2.js <==
var searchData=
[
  ['cancel_0',['cancel',['../classboost_1_1redis_1_1basic__connection.html#ab91c1de2894180d9bc9ae35b188f078a',1,'boost::redis::basic_connection::cancel()'],['../classboost_1_1redis_1_1connection.html#a95d4d441d5cc6e9809de9e18c2a19ca8',1,'boost::redis::connection::cancel()'],['../classboost_1_1redis_1_1detail_1_1connection__base.html#ae0f65b3d236d7f48b8374efc2b0fd357',1,'boost::redis::detail::connection_base::cancel()']]],
  ['cancel_5fif_5fnot_5fconnected_1',['cancel_if_not_connected',['../classboost_1_1redis_1_1request.html#a3225a8a42083e807cd7b699bbd33707a',1,'boost::redis::request::config']]],
  ['cancel_5fif_5funresponded_2',['cancel_if_unresponded',['../classboost_1_1redis_1_1request.html#abbc65c9264a6732bdd157078507479ab',1,'boost::redis::request::config']]],
  ['cancel_5fon_5fconnection_5flost_3',['cancel_on_connection_lost',['../classboost_1_1redis_1_1request.html#ad871157d771d49b6ea3cd0707280256f',1,'boost::redis::request::config']]],
  ['clear_4',['clear',['../classboost_1_1redis_1_1request.html#ac880af0951bfae6b89913913ac709557',1,'boost::redis::request']]],
  ['clientname_5',['clientname',['../group__high-level-api.html#a3388584bc6c20946f824e35602b51c4e',1,'boost::redis::config']]],
  ['commands_5fsent_6',['commands_sent',['../group__high-level-api.html#a8f06258bcaad903476f39a56e9049c61',1,'boost::redis::usage']]],
  ['config_7',['config',['../group__high-level-api.html#structboost_1_1redis_1_1config',1,'boost::redis::config'],['../classboost_1_1redis_1_1request.html#structboost_1_1redis_1_1request_1_1config',1,'boost::redis::request::config']]],
  ['connect_8',['connect',['../group__high-level-api.html#ggaaf95d0d45b3829342e8adff2d6c3fcbeab640a0ce465fa2a4150c36b305c1c11b',1,'boost::redis']]],
  ['connect_5ftimeout_9',['connect_timeout',['../group__high-level-api.html#ac01a8bcfc1acd353acc62b69f0648442',1,'boost::redis::config::connect_timeout()'],['../group__high-level-api.html#gga657dd981aeeec394a381d3fb4a2222bea68fe378b7acbea462cde519f2d27ed71',1,'connect_timeout()boost::redis']]],
  ['connection_10',['connection',['../classboost_1_1redis_1_1connection.html',1,'boost::redis::connection'],['../classboost_1_1redis_1_1connection.html#a626feecc5787c1646434c71211fa0ae8',1,'boost::redis::connection::connection(executor_type ex, asio::ssl::context ctx=asio::ssl::context{asio::ssl::context::tlsv12_client}, std::size_t max_read_size=(std::numeric_limits&lt; std::size_t &gt;::max)())'],['../classboost_1_1redis_1_1connection.html#a77fb6184b1637a808b3edaaad6c19931',1,'boost::redis::connection::connection(asio::io_context &amp;ioc, asio::ssl::context ctx=asio::ssl::context{asio::ssl::context::tlsv12_client}, std::size_t max_read_size=(std::numeric_limits&lt; std::size_t &gt;::max)())']]],
  ['connection_5fbase_11',['connection_base',['../classboost_1_1redis_1_1detail_1_1connection__base.html',1,'boost::redis::detail::connection_base&lt; Executor &gt;'],['../classboost_1_1redis_1_1detail_1_1connection__base.html#af0984b05a10be596c8814c45c5558390',1,'boost::redis::detail::connection_base::connection_base()']]],
  ['connection_5fbase_3c_20executor_5ftype_20_3e_12',['connection_base&lt; executor_type &gt;',['../classboost_1_1redis_1_1detail_1_1connection__base.html',1,'boost::redis::detail']]],
  ['crit_13',['crit',['../group__high-level-api.html#gga4f66f8e4497ccf09e57440515d806feba5888c6a8bb862595985926d16c7dcf13',1,'boost::redis::logger']]]
];
